unit IcmpApi;

interface

Uses
  Windows, Messages, SysUtils, Classes, Controls, StdCtrls, ExtCtrls;

Type
  TIPAddr = Integer;          // IP Address
  PIPOptionInformation = ^TIPOptionInformation;
  TIPOptionInformation = Record
    Ttl         : Byte;       // Time To Live
    Tos         : Byte;       // Type of Service
    Flags       : Byte;       // IP Header Flags
    OptionsSize : Byte;       // Size In bytes of options data
    OptionsData : ^Byte;      // Pointer to options data
  end;

  TIcmpEchoReply = record
    Address       : TIPAddr;              // Replying address
    Status        : ULONG;                // Reply IP_STATUS
    RoundTripTime : ULONG;                // RTT in milliseconds
    DataSize      : ULONG;                // Reply data size in bytes
    Reserved      : ULONG;                // Reserved for system use
    Data          : Pointer;              // Pointer to the reply data
    Options       : PIPOptionInformation; // Reply options
  end;

Const
  IP_STATUS_BASE              = 11000;

  IP_SUCCESS                  = 0;
  IP_BUF_TOO_SMALL            = (IP_STATUS_BASE + 1);
  IP_DEST_NET_UNREACHABLE     = (IP_STATUS_BASE + 2);
  IP_DEST_HOST_UNREACHABLE    = (IP_STATUS_BASE + 3);
  IP_DEST_PROT_UNREACHABLE    = (IP_STATUS_BASE + 4);
  IP_DEST_PORT_UNREACHABLE    = (IP_STATUS_BASE + 5);
  IP_NO_RESOURCES             = (IP_STATUS_BASE + 6);
  IP_BAD_OPTION               = (IP_STATUS_BASE + 7);
  IP_HW_ERROR                 = (IP_STATUS_BASE + 8);
  IP_PACKET_TOO_BIG           = (IP_STATUS_BASE + 9);
  IP_REQ_TIMED_OUT            = (IP_STATUS_BASE + 10);
  IP_BAD_REQ                  = (IP_STATUS_BASE + 11);
  IP_BAD_ROUTE                = (IP_STATUS_BASE + 12);
  IP_TTL_EXPIRED_TRANSIT      = (IP_STATUS_BASE + 13);
  IP_TTL_EXPIRED_REASSEM      = (IP_STATUS_BASE + 14);
  IP_PARAM_PROBLEM            = (IP_STATUS_BASE + 15);
  IP_SOURCE_QUENCH            = (IP_STATUS_BASE + 16);
  IP_OPTION_TOO_BIG           = (IP_STATUS_BASE + 17);
  IP_BAD_DESTINATION          = (IP_STATUS_BASE + 18);

  IP_ADDR_DELETED            = (IP_STATUS_BASE + 19);
  IP_SPEC_MTU_CHANGE          = (IP_STATUS_BASE + 20);
  IP_MTU_CHANGE               = (IP_STATUS_BASE + 21);
  IP_UNLOAD                   = (IP_STATUS_BASE + 22);
  IP_ADDR_ADDED               = (IP_STATUS_BASE + 23);

  IP_GENERAL_FAILURE          = (IP_STATUS_BASE + 50);
  MAX_IP_STATUS               = IP_GENERAL_FAILURE;
  IP_PENDING                  = (IP_STATUS_BASE + 255);

  IP_FLAG_DF      = $02;         // Don't fragment this packet.

  IP_OPT_EOL      = 0;          // End of list option
  IP_OPT_NOP      = 1;          // No operation
  IP_OPT_SECURITY = $82;        // Security option
  IP_OPT_LSRR     = $83;        // Loose source route
  IP_OPT_SSRR     = $89;        // Strict source route
  IP_OPT_RR       = $07;        // Record route
  IP_OPT_TS       = $44;        // Timestamp
  IP_OPT_SID      = $88;        // Stream ID (obsolete)

  MAX_OPT_SIZE    = 40;         // Maximum length of IP options in bytes


Function IcmpCreateFile : THandle; StdCall;

function IcmpCloseHandle(IcmpHandle : THandle) : BOOL; StdCall;
Function IcmpSendEcho(IcmpHandle         : THandle;
                      DestinationAddress : TIPAddr;
                      RequestData        : Pointer;
                      RequestSize        : Word;
                      RequestOptions     : PIPOptionInformation;
                      ReplyBuffer        : Pointer;
                      ReplySize          : DWord;
                      Timeout            : DWord) : DWord; StdCall;

implementation

Const
  IcmpDll = 'Icmp.dll';

Function IcmpCreateFile; External IcmpDll Name 'IcmpCreateFile';
Function IcmpCloseHandle; External IcmpDll Name 'IcmpCloseHandle';
Function IcmpSendEcho; External IcmpDll Name 'IcmpSendEcho';

end.

